@@ -1,9 +1,16 @@
 #!/usr/bin/env python
 
-import typing
+import sys
+
+if sys.version_info >= (3, 8):
+    from typing import List, Literal, Optional, TypedDict
+else:
+    from typing import List, Optional
+
+    from typing_extensions import Literal, TypedDict
 
 
-class S3BatchRequestJob(typing.TypedDict):
+class S3BatchRequestJob(TypedDict):
     """
     S3BatchRequestJob
 
@@ -15,7 +22,7 @@ class S3BatchRequestJob(typing.TypedDict):
     id: str
 
 
-class S3BatchRequestTask(typing.TypedDict):
+class S3BatchRequestTask(TypedDict):
     """
     S3BatchRequestTask
 
@@ -25,18 +32,18 @@ class S3BatchRequestTask(typing.TypedDict):
 
     s3Key: str
 
-    s3VersionId: typing.Optional[str]
+    s3VersionId: Optional[str]
 
     s3BucketArn: str
     """
 
     taskId: str
     s3Key: str
-    s3VersionId: typing.Optional[str]
+    s3VersionId: Optional[str]
     s3BucketArn: str
 
 
-class S3BatchEvent(typing.TypedDict):
+class S3BatchEvent(TypedDict):
     """
     S3BatchEvent https://docs.aws.amazon.com/lambda/latest/dg/services-s3-batch.html
 
@@ -48,16 +55,16 @@ class S3BatchEvent(typing.TypedDict):
 
     job: :py:class:`S3BatchRequestJob`
 
-    tasks: typing.List[:py:class:`S3BatchRequestTask`]
+    tasks: List[:py:class:`S3BatchRequestTask`]
     """
 
     invocationSchemaVersion: str
     invocationId: str
     job: S3BatchRequestJob
-    tasks: typing.List[S3BatchRequestTask]
+    tasks: List[S3BatchRequestTask]
 
 
-class S3BatchResponseResult(typing.TypedDict):
+class S3BatchResponseResult(TypedDict):
     """
     S3BatchRequestTask
 
@@ -75,7 +82,7 @@ class S3BatchResponseResult(typing.TypedDict):
     resultString: str
 
 
-class S3BatchResponse(typing.TypedDict):
+class S3BatchResponse(TypedDict):
     """
     S3BatchResponse https://docs.aws.amazon.com/lambda/latest/dg/services-s3-batch.html
 
@@ -83,14 +90,14 @@ class S3BatchResponse(typing.TypedDict):
     ----------
     invocationSchemaVersion: str
 
-    treatMissingKeysAs: typing.Literal['Succeeded', 'TemporaryFailure', 'PermanentFailure']
+    treatMissingKeysAs: Literal['Succeeded', 'TemporaryFailure', 'PermanentFailure']
 
     invocationId: str
 
-    results: typing.List[:py:class:`S3BatchResponseResult`]
+    results: List[:py:class:`S3BatchResponseResult`]
     """
 
     invocationSchemaVersion: str
-    treatMissingKeysAs: typing.Literal['Succeeded', 'TemporaryFailure', 'PermanentFailure']
+    treatMissingKeysAs: Literal['Succeeded', 'TemporaryFailure', 'PermanentFailure']
     invocationId: str
-    results: typing.List[S3BatchResponseResult]
+    results: List[S3BatchResponseResult]
